import os

from django.utils.translation import ugettext_lazy as _
from django_auth_ldap.config import LDAPSearch, GroupOfNamesType
import ldap

from ._version import __version__ as VERSION

# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))


# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/1.11/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = '0*nfm5dzrtt4@k8!&ihqe9*b5210qx@!x$g&*f&ze9azb_0jb*'

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = False

ALLOWED_HOSTS = ['*']

# DISALLOWED STUFF
DISALLOWED_UIDS = [
    '_apt',
    'backup',
    'bacula',
    'bareos',
    'bin',
    'daemon',
    'Debian-exim',
    'freerad',
    'games',
    'gnats',
    'irc',
    'list',
    'lp',
    'mail',
    'man',
    'messagebus',
    'news',
    'nslcd',
    'ntp',
    'openldap',
    'postfix',
    'postgres',
    'proxy',
    'root',
    'sshd',
    'sssd',
    'statd',
    'sync',
    'sys',
    'systemd-bus-proxy',
    'systemd-network',
    'systemd-resolve',
    'systemd-timesync',
    'uucp',
    'www-data']
DISALLOWED_LOCAL_PARTS = DISALLOWED_UIDS + ['webmaster', 'hostmaster', 'postmaster']

# MAINTENANCE_MODE
MAINTENANCE_MODE = None
MAINTENANCE_MODE_IGNORE_ADMIN_SITE = True
MAINTENANCE_MODE_IGNORE_STAFF = True

# Application definition

INSTALLED_APPS = [
    'bootstrap4',
    'fa',
    'ticdesk',
    'ticdesk_account.apps.TicdeskAccountConfig',
    'ticdesk_org.apps.TicdeskOrgConfig',
    'ticdesk_events.apps.TicdeskEventsConfig',
    'django_extensions',
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'django_starfield',
    'django_filters',
    'django_tables2',
    'django_cron',
    'maintenance_mode',
    'leaflet',
]

MIDDLEWARE = [
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.locale.LocaleMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'ticdesk_account.middleware.check_current_person',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
    'maintenance_mode.middleware.MaintenanceModeMiddleware',
]

CRON_CLASSES = [
#    'ticdesk_account.cron.CleanGroups',
#    'ticdesk_account.cron.CleanPersons',
    'ticdesk_account.cron.BirthdayMails',
    'django_cron.cron.FailedRunsNotificationCronJob'
]

ROOT_URLCONF = 'ticdesk.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [os.path.join(BASE_DIR, 'ticdesk', 'templates')],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
                'django.template.context_processors.request',
                'ticdesk.contextprocessors.person_context',
                'maintenance_mode.context_processors.maintenance_mode',
            ],
        },
    },
]

WSGI_APPLICATION = 'ticdesk.wsgi.application'


with open("/etc/teckids/ticdesk.conf") as f:
    exec(f.read())

DATABASES = {
    'default': {
        'CONN_MAX_AGE': 0,
        'ENGINE': 'django.db.backends.postgresql_psycopg2',
        'HOST': 'db-vip.teckids.org',
        'NAME': 'ticdesk',
        'PASSWORD': POSTGRES_PASSWORD,
        'PORT': '5432',
        'USER': 'ticdesk',
    },
    'ldap': {
        'ENGINE': 'ldapdb.backends.ldap',
        'NAME': LDAP_SERVER_URI,
        'USER': LDAP_BIND_DN,
        'PASSWORD': LDAP_BIND_PASSWORD,
        'CONNECTION_OPTIONS': {
            ldap.OPT_DEREF: ldap.DEREF_ALWAYS
        }
    }
}

DATABASE_ROUTERS = ['ldapdb.router.Router']

AUTH_PASSWORD_VALIDATORS = [
    {
        'NAME': 'django.contrib.auth.password_validation.UserAttributeSimilarityValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.MinimumLengthValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.CommonPasswordValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.NumericPasswordValidator',
    },
]


LANGUAGE_CODE = 'de'

LANGUAGES = [
    ('de', _('German')),
    ('en', _('English')),
]

TIME_ZONE = 'Europe/Berlin'

USE_I18N = True

USE_L10N = True

USE_TZ = True


DATA_DIR = '/srv/www/ticdesk/data'
STATIC_URL = '/static/'
MEDIA_URL = '/media/'

STATICFILES_DIRS = [
    os.path.join(BASE_DIR, "ticdesk", "static"),
]

ADMINS = [('Teckids e.V. Admins', 'root@teckids.org')]
DEFAULT_FROM_EMAIL = 'www-data@ticdesk.teckids.org'
SERVER_EMAIL = 'www-data@ticdesk.teckids.org'
EMAIL_SUBJECT_PREFIX = '[TIC-Desk] '

LOGIN_URL = '/account/login'

AUTH_LDAP_SERVER_URI = LDAP_SERVER_URI
AUTHENTICATION_BACKENDS = (
    'django_auth_ldap.backend.LDAPBackend',
    'django.contrib.auth.backends.ModelBackend'
)
AUTH_LDAP_CONNECTION_OPTIONS = {
    ldap.OPT_REFERRALS: 0
}
AUTH_LDAP_BIND_DN = LDAP_BIND_DN
AUTH_LDAP_BIND_PASSWORD = LDAP_BIND_PASSWORD
AUTH_LDAP_USER_SEARCH = LDAPSearch("ou=People,dc=teckids,dc=org",
                                   ldap.SCOPE_SUBTREE, "(uid=%(user)s)")
AUTH_LDAP_GROUP_SEARCH = LDAPSearch("ou=Groups,dc=teckids,dc=org",
                                    ldap.SCOPE_SUBTREE, "(objectClass=groupOfNames)"
                                    )
AUTH_LDAP_GROUP_TYPE = GroupOfNamesType(name_attr='cn')
AUTH_LDAP_FIND_GROUP_PERMS = True
AUTH_LDAP_MIRROR_GROUPS = True
AUTH_LDAP_USER_ATTR_MAP = {
    "first_name": "givenName",
    "last_name": "sn",
    "email": "mail"
}

BOOTSTRAP4 = {
    "css_url": "/javascript/bootstrap4/css/bootstrap.min.css",
    "javascript_url": "/javascript/bootstrap4/js/bootstrap.min.js",
    "jquery_url": "/javascript/jquery/jquery.min.js",
    "popper_url": "/javascript/popper.js/popper.min.js",
    "include_jquery": True
}

FONT_AWESOME = {'url': '/javascript/font-awesome/css/font-awesome.min.css'}


# django-starfield
STARFIELD_CODEPOINT = '1F42C'

BIRTHDAY_FORMAT = '%Y-%m-%d'

USER_AGENT = 'TIC-Desk/%s' % VERSION

TICDESK_USER_INITIAL_SUFFIX = '@TECKIDS.ORG_legacy'

WWS_POST_URL = 'https://commu-intern.teckids.org/wws'

MAIL_DOMAINS = ['bessermailer.de', 'kinder.email',
                'mag-kekse.de', 'mag-roboter.de', 'kaesesocken.de']

NEWSLETTER_CHOICES = [
    ('none', _('Keine Informationen erhalten')),
    ('kinder', _('Informationen und Einladungen für Kinder erhalten')),
    ('eltern', _('Informationen und Einladungen für Eltern erhalten')),
    ('lehrer', _('Informationen und Einladungen für Lehrer erhalten')),
    ('hacker', _('Informationen für Hacker, Konferenz-Organisatoren u.ä. erhalten'))
]

SILENCED_SYSTEM_CHECKS = ['models.E026']

with open("/etc/teckids/ticdesk.conf") as f:
    exec(f.read())

STATIC_ROOT = os.path.join(DATA_DIR, 'static')
MEDIA_ROOT = os.path.join(DATA_DIR, 'media')
