from datetime import datetime

from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool
from django.template.loader import get_template
import pytz

from ticdesk_account.models import TeckidsGroup
from ticdesk_events.models import TeckidsProject

from .models import LDAPGroupList, UpcomingEventsList


class LDAPGroupListPlugin(CMSPluginBase):
    model = LDAPGroupList
    module = "TIC-Desk / Teckids Plugins"
    name = "Listing of LDAP group"
    render_template = "ldaplist.html"
    cache = False

    def get_render_template(self, context, instance, placeholder):
        return get_template('ldaplist/%s.html' % instance.instance_name)

    def render(self, context, instance, placeholder):
        context = super(LDAPGroupListPlugin, self).render(context, instance, placeholder)

        ldap_entries = list(TeckidsGroup.objects.get(cn=instance.group_cn).members_persons)
        context['ldap_entries'] = ldap_entries

        return context


class UpcomingEventsListPlugin(CMSPluginBase):
    model = UpcomingEventsList
    module = "TIC-Desk / Teckids Plugins"
    name = "Upcoming Events"
    render_template = "ticdesk_cmsstuff/events_mini.html"
    cache = False

    def render(self, context, instance, placeholder):
        context = super(UpcomingEventsListPlugin, self).render(context, instance, placeholder)

        # Get all upcoming events
        now = datetime.today().replace(tzinfo=pytz.UTC)
        events = TeckidsProject.objects.filter(
            date_event__gte=now, published=True)[0:instance.count]
        context['events'] = events

        return context


plugin_pool.register_plugin(LDAPGroupListPlugin)
plugin_pool.register_plugin(UpcomingEventsListPlugin)
