from datetime import datetime

from django.core.exceptions import ObjectDoesNotExist
from django.http import HttpResponseNotFound
from django.shortcuts import render
import pytz

from ticdesk_events.models import TeckidsProject

from .models import TeckidsEventPublication


def events(request):
    context = {}

    # Get all upcoming events
    now = datetime.today().replace(tzinfo=pytz.UTC)
    events = TeckidsProject.objects.filter(date_event__gte=now, published=True)
    context['events'] = events

    return render(request, 'ticdesk_cmsstuff/events.html', context)


def event(request, cn):
    context = {}

    # Get the event
    try:
        event = TeckidsProject.objects.get(cn=cn)
    except ObjectDoesNotExist:
        # Turn not-found object into a 404 error
        return HttpResponseNotFound(render(request, 'ticdesk_cmsstuff/event.html', context))

    context['event'] = event

    # Get the CMS publication instance
    publication = TeckidsEventPublication.objects.get_or_create(cn=cn)[0]
    context['publication'] = publication

    return render(request, 'ticdesk_cmsstuff/event.html', context)
